'''azurerm - library for easy Azure Resource Manager calls from Python'''

from .acs import *
from .adalfns import *
from .amsrp import *
from .container import *
from .computerp import *
from .cosmosdbrp import *
from .deployments import *
from .insightsrp import *
from .networkrp import *
from .resourcegroups import *
from .storagerp import *
from .subfns import *
from .restfns import *
from .templates import *
from .vmimages import *
